@@ -277,6 +277,18 @@ check_foreign_folder_thread (GObject *with_object,
 			g_object_unref (conn);
 			return;
 		}
+
+		if (!cffd->user_displayname)
+			cffd->user_displayname = display_name;
+		else
+			g_free (display_name);
+
+		if (email_address && *email_address) {
+			g_free (cffd->email);
+			cffd->email = email_address;
+		} else {
+			g_free (email_address);
+		}
 	}
 
 	if (g_cancellable_set_error_if_cancelled (cancellable, perror)) {
@@ -794,7 +806,7 @@ e_ews_subscribe_foreign_folder_resolve_name_sync (EEwsConnection *cnc,
 
 	if (!e_ews_connection_resolve_names_sync (cnc, G_PRIORITY_DEFAULT,
 		name, EWS_SEARCH_AD, NULL, FALSE,
-		&mailboxes, NULL, &includes_last_item,
+		&includes_last_item, &mailboxes, NULL,
 		cancellable, &local_error)) {
 		if (g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_NAMERESOLUTIONNORESULTS) ||
 		    g_error_matches (local_error, EWS_CONNECTION_ERROR, EWS_CONNECTION_ERROR_NAMERESOLUTIONNOMAILBOX)) {
